@@ -130,17 +130,16 @@ static void
 cal_dialog_setup_option_menu (DialogData *data)
 {
 	GtkOptionMenu *option_menu;
-	GSList        *types;
+	GList         *types, *l;
 	GtkWidget     *menu;
 	GtkWidget     *menu_item;
 	const gchar   *name;
-	GSList        *l;
 	MrpDay        *day;
 
 	types = mrp_day_get_all (data->project);
 
-	types = g_slist_prepend (types, mrp_day_get_nonwork ());
-	types = g_slist_prepend (types, mrp_day_get_work ());
+	types = g_list_prepend (types, mrp_day_get_nonwork ());
+	types = g_list_prepend (types, mrp_day_get_work ());
 
 	option_menu = GTK_OPTION_MENU (data->option_menu);
 	menu = gtk_option_menu_get_menu (option_menu);
@@ -168,7 +167,7 @@ cal_dialog_setup_option_menu (DialogData *data)
 	gtk_widget_show (menu);
 	gtk_option_menu_set_menu (option_menu, menu);
 
-	g_slist_free (types);
+	g_list_free (types);
 }
 
 static void
@@ -664,7 +663,7 @@ static void
 cal_dialog_update_day_widgets (DialogData *data)
 {
 	MrpDay      *day;
-	GSList      *ivals, *l;
+	GList       *ivals, *l;
 	MrpCalendar *calendar, *root;
 	MgCalendar  *calendar_widget;
 	guint        y, m, d;
@@ -838,7 +837,7 @@ cal_dialog_build_tree (GtkTreeStore *store,
 {
 	GtkTreeIter  iter;
 	const gchar *name;
-	GSList      *children, *l;
+	GList       *children, *l;
 		
 	name = mrp_calendar_get_name (calendar);
 	
@@ -861,7 +860,7 @@ cal_dialog_tree_changed (MrpProject  *project,
 			 GtkTreeView *tree_view)
 {
 	GtkTreeStore *store;
-	GSList       *children, *l;
+	GList        *children, *l;
 
 	g_return_if_fail (MRP_IS_PROJECT (project));
 	g_return_if_fail (MRP_IS_CALENDAR (root));
@@ -885,7 +884,7 @@ cal_dialog_create_model (MrpProject  *project,
 {
 	GtkTreeStore *store;
 	MrpCalendar  *root;
-	GSList       *children, *l;
+	GList        *children, *l;
 
 	root = mrp_project_get_root_calendar (project);
 
