@@ -573,8 +573,8 @@ mpp_setup_properties_list (GtkWidget *dialog)
 		gtk_list_store_new (NUM_OF_COLS, G_TYPE_POINTER));
 	gtk_tree_view_set_model (data->properties_tree, model);
 	
-	properties = mrp_project_get_properties (data->project,
-						 MRP_TYPE_PROJECT);
+	properties = mrp_project_get_properties_from_type (data->project,
+							   MRP_TYPE_PROJECT);
 	
 	for (l = properties; l; l = l->next) {
 		MrpProperty *property = MRP_PROPERTY (l->data);
@@ -663,7 +663,7 @@ mpp_property_value_data_func (GtkTreeViewColumn *tree_column,
 	
 	gtk_tree_model_get (tree_model, iter, COL_PROPERTY, &property, -1);
 
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
@@ -1112,7 +1112,7 @@ mpp_property_value_edited (GtkCellRendererText *cell,
 			    COL_PROPERTY, &property,
 			    -1);
 	
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
 		mrp_object_set (MRP_OBJECT (project),
