@@ -489,7 +489,6 @@ resource_dialog_resource_group_changed_cb (MrpResource *resource,
 	} else {
 		index = g_list_index (groups, group) + 1;
 	}
-	g_list_free (groups);
 
 	gtk_option_menu_set_history (GTK_OPTION_MENU (data->group_menu), index);
 	
@@ -788,7 +787,7 @@ resource_dialog_build_calendar_tree_recurse (GtkTreeStore *store,
 {
 	GtkTreeIter  iter;
 	const gchar *name;
-	GSList      *children, *l;
+	GList       *children, *l;
 		
 	name = mrp_calendar_get_name (calendar);
 	
@@ -813,7 +812,7 @@ resource_dialog_build_calendar_tree (DialogData *data)
 	MrpCalendar  *root;
 	GtkTreeStore *store;
 	GtkTreeIter   iter;
-	GSList       *children, *l;
+	GList        *children, *l;
 	MrpCalendar  *calendar;
 
 	project = mg_main_window_get_project (data->main_window);
@@ -1132,9 +1131,9 @@ mg_resource_dialog_new (MgMainWindow *window,
 		index = g_list_index (groups, group) + 1;
 	}
 	
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->group_menu), index);
+	gtk_option_menu_set_history (GTK_OPTION_MENU (data->group_menu), 
+				     index);
 	
-	g_list_free (groups);
 
 	g_signal_connect (data->group_menu,
 			  "changed",
