@@ -442,7 +442,7 @@ gantt_background_draw (GnomeCanvasItem *item,
 	mrptime                ival_start, ival_end, ival_prev;
 	MrpCalendar           *calendar;
 	MrpDay                *day;
-	GSList                *ivals, *l;
+	GList                 *ivals, *l;
 	MrpInterval           *ival;
 	gint                   level;
 
