@@ -189,7 +189,8 @@ static void        gantt_chart_tree_node_insert_path    (TreeNode           *nod
 static void        gantt_chart_tree_node_dump           (TreeNode           *node);
 static TreeNode *  gantt_chart_tree_node_at_path        (TreeNode           *root,
 							 GtkTreePath        *path);
-static void        gantt_chart_tree_node_remove         (TreeNode           *node);
+static void        gantt_chart_tree_node_remove         (MgGanttChart       *chart,
+							 TreeNode           *node);
 static void        gantt_chart_tree_traverse            (TreeNode           *node,
 							 TreeFunc            func,
 							 gpointer            data);
@@ -713,7 +714,7 @@ gantt_chart_row_deleted (GtkTreeModel *model,
 
 	node = gantt_chart_tree_node_at_path (chart->priv->tree, path);
 
-	gantt_chart_tree_node_remove (node);
+	gantt_chart_tree_node_remove (chart, node);
 	gantt_chart_remove_children (chart, node);
 
 	gantt_chart_tree_node_dump (chart->priv->tree);
@@ -791,7 +792,7 @@ gantt_chart_build_relations (MgGanttChart *chart,
 		task = mg_gantt_model_get_task (MG_GANTT_MODEL (priv->model),
 						iter);
 		
-		relations = mrp_task_get_predecessors (task);
+		relations = mrp_task_get_predecessor_relations (task);
 		for (l = relations; l; l = l->next) {
 			relation = l->data;
 
@@ -1001,7 +1002,7 @@ gantt_chart_insert_task (MgGanttChart *chart,
 	TreeNode         *tree_node;
 
 	priv = chart->priv;
-	
+
 	item = gnome_canvas_item_new (gnome_canvas_root (priv->canvas),
 				      MG_TYPE_GANTT_ROW,
 				      "task", task,
@@ -1090,7 +1091,7 @@ mg_gantt_chart_expand_row (MgGanttChart *chart, GtkTreePath *path)
 	TreeNode *node;
 
 	g_return_if_fail (MG_IS_GANTT_CHART (chart));
-	
+
 	node = gantt_chart_tree_node_at_path (chart->priv->tree, path);
 
 	if (node) {
@@ -1223,7 +1224,7 @@ gantt_chart_task_moved_task_traverse_func (MrpTask *task, MgGanttChart *chart)
 
 	row = gantt_chart_get_row_from_task (chart, task);
 
-	relations = mrp_task_get_predecessors (task);
+	relations = mrp_task_get_predecessor_relations (task);
 	for (l = relations; l; l = l->next) {
 		relation = l->data;
 		
@@ -1233,7 +1234,7 @@ gantt_chart_task_moved_task_traverse_func (MrpTask *task, MgGanttChart *chart)
 		}
 	}
 	
-	relations = mrp_task_get_successors (task);
+	relations = mrp_task_get_successor_relations (task);
 	for (l = relations; l; l = l->next) {
 		relation = l->data;
 		
@@ -1454,7 +1455,7 @@ gantt_chart_tree_node_insert_path (TreeNode *node, GtkTreePath *path, TreeNode *
 }
 
 static void
-gantt_chart_tree_node_remove (TreeNode *node)
+gantt_chart_tree_node_remove (MgGanttChart *chart, TreeNode *node)
 {
 	TreeNode *parent;
 	gint     i, pos;
@@ -1478,6 +1479,9 @@ gantt_chart_tree_node_remove (TreeNode *node)
 	parent->num_children--;
 	parent->children = g_realloc (parent->children, sizeof (gpointer) * parent->num_children);
 
+	g_signal_handlers_disconnect_by_func (node->task, gantt_chart_relation_added, chart);
+	g_signal_handlers_disconnect_by_func (node->task, gantt_chart_relation_removed, chart);
+	
 	node->parent = NULL;
 }
 
@@ -1490,6 +1494,14 @@ gantt_chart_tree_node_at_path (TreeNode *node, GtkTreePath *path)
 	indices = gtk_tree_path_get_indices (path);
 
 	for (i = 0; i < depth; i++) {
+		/* FIXME: workaround for a bug in the gantt view, the
+		 * row_expanded (and collapsed) should not be handled before we
+		 * have inserted the rows.
+		 */
+		if (node->num_children <= indices[i]) {
+			return NULL;
+		}
+		
 		node = node->children[indices[i]];
 	}
 	
@@ -1499,9 +1511,9 @@ gantt_chart_tree_node_at_path (TreeNode *node, GtkTreePath *path)
 static void
 gantt_chart_tree_node_dump_do (TreeNode *node, gint depth)
 {
-	gint i;
+	gint     i;
 	MrpTask *task;
-	gchar *name;
+	gchar   *name;
 
 	if (node == NULL) {
 		return;
@@ -1516,14 +1528,20 @@ gantt_chart_tree_node_dump_do (TreeNode *node, gint depth)
 			g_object_get (node->item, "task", &task, NULL);
 			g_object_get (task, "name", &name, NULL);
 		} else {
-			name = "????";
+			name = g_strdup ("<corrupt tree>");
 		}
 	} else {
-		name = "Root";
+		name = g_strdup ("Root");
+	}
+
+	if (!name || !name[0]) {
+		name = g_strdup ("No name");
 	}
 	
 	g_print ("%s\t\t%c\n", name, node->expanded ? 'E' : 'C');
 	
+	g_free (name);
+	
 	for (i = 0; i < node->num_children; i++) {
 		gantt_chart_tree_node_dump_do (node->children[i], depth + 1);
 	}
