@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 CodeFactory AB
- * Copyright (C) 2001-2002 Richard Hult <rhult@codefactory.se>
+ * Copyright (C) 2001-2003 CodeFactory AB
+ * Copyright (C) 2001-2003 Richard Hult <rhult@codefactory.se>
  * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
@@ -127,10 +127,11 @@ mg_gantt_model_get_type (void)
 static void
 gantt_model_connect_to_task_signals (MgGanttModel *model, MrpTask *task)
 {
-	g_signal_connect (task,
-			  "notify",
-			  G_CALLBACK (gantt_model_task_notify_cb),
-			  model);
+	g_signal_connect_object (task,
+				 "notify",
+				 G_CALLBACK (gantt_model_task_notify_cb),
+				 model,
+				 0);
 }
 
 static void
@@ -190,6 +191,10 @@ static gboolean
 traverse_remove_subtree (GNode        *node,
 			 MgGanttModel *model)
 {
+	g_signal_handlers_disconnect_by_func (node->data,
+					      gantt_model_task_notify_cb,
+					      model);
+	
 	g_hash_table_remove (model->priv->task2node_hash, node->data);
 
 	return FALSE;
@@ -224,13 +229,19 @@ gantt_model_task_removed_cb (MrpProject   *project,
 	gboolean     has_child_toggled;
 
 	g_signal_emit (model, signals[TASK_REMOVED], 0, task);
-
+	
+	node = g_hash_table_lookup (model->priv->task2node_hash, task);
+	if (!node) {
+		/* This happens if we are already removed when a parent was
+		 * removed. 
+		 */
+		return; 
+	}
+	
 	g_signal_handlers_disconnect_by_func (task,
 					      gantt_model_task_notify_cb,
 					      model);
-
-	node = g_hash_table_lookup (model->priv->task2node_hash, task);
-
+	
 	parent_node = node->parent;
 	
 	path = gantt_model_get_path_from_node (model, node);
@@ -286,7 +297,6 @@ gantt_model_reattach_subtasks (GtkTreeModel *tree_model,
 		pos = mrp_task_get_position (child);
 		g_node_insert (parent_node, pos, node);
 		
-		//-----
 #if 1
 		{
 			gboolean has_child_toggled;
@@ -306,7 +316,6 @@ gantt_model_reattach_subtasks (GtkTreeModel *tree_model,
 			}
 		}
 #endif
-		//-----
 		
 		path = mg_gantt_model_get_path_from_task (model, child);
 		gtk_tree_model_get_iter (tree_model, &iter, path);
@@ -421,7 +430,7 @@ gantt_model_task_notify_cb (MrpTask      *task,
 	GtkTreeModel *tree_model;
 	GtkTreePath  *path;
 	GtkTreeIter   iter;
-	
+
 	tree_model = GTK_TREE_MODEL (model);
 	
 	path = mg_gantt_model_get_path_from_task (model, task);
@@ -442,6 +451,38 @@ traverse_insert_task_into_hash (GNode        *node,
 	return FALSE;
 }
 
+static void
+traverse_setup_tree (MrpTask  *task,
+		     GNode    *node)
+{
+	MrpTask *child_task;
+	GNode   *child_node;
+
+	child_task = mrp_task_get_first_child (task);
+	while (child_task) {
+		child_node = g_node_new (child_task);
+		g_node_append (node, child_node);
+
+		traverse_setup_tree (child_task, child_node);
+		
+		child_task = mrp_task_get_next_sibling (child_task);
+	}
+}
+
+static GNode *
+gantt_model_setup_task_tree (MgGanttModel *model)
+{
+	MrpTask *root_task;
+	GNode   *root_node;
+
+	root_task = mrp_project_get_root_task (model->priv->project); 
+	root_node = g_node_new (root_task);
+
+	traverse_setup_tree (root_task, root_node);
+
+	return root_node;
+}
+
 MgGanttModel *
 mg_gantt_model_new (MrpProject *project)
 {
@@ -453,7 +494,7 @@ mg_gantt_model_new (MrpProject *project)
 	priv = model->priv;
 
 	priv->project = project;
-	priv->tree = mrp_project_get_task_tree (project);
+	priv->tree = gantt_model_setup_task_tree (model);
 
 	g_node_traverse (priv->tree,
 			 G_PRE_ORDER,
@@ -494,9 +535,13 @@ static void
 gantt_model_finalize (GObject *object)
 {
 	MgGanttModel *model = MG_GANTT_MODEL (object);
+
+	g_node_destroy (model->priv->tree);
+	g_hash_table_destroy (model->priv->task2node_hash);
 	
 	g_free (model->priv);
-	
+	model->priv = NULL;
+
 	if (G_OBJECT_CLASS (parent_class)->finalize) {
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 	}
@@ -670,6 +715,9 @@ mg_gantt_model_get_path_from_task (MgGanttModel *model,
 
 	node = g_hash_table_lookup (model->priv->task2node_hash, task);
 
+	/* Help debugging. */
+	g_return_val_if_fail (node != NULL, NULL);
+	
 	return gantt_model_get_path_from_node (model, node);
 }
 
@@ -757,7 +805,8 @@ gantt_model_get_value (GtkTreeModel *tree_model,
 
 		/* We don't support negative slack yet. */
 		if (t2 >= t1) {
-			duration = mrp_project_calculate_task_work (project, task, t2 - t1);
+			duration = mrp_project_calculate_task_work (
+				project, task, t1, t2);
 		} else {
 			duration = 0;
 		}
