@@ -39,8 +39,8 @@
 #define INDENT_FACTOR 4
 
 typedef struct {
-	GSList  *first_task;
-	GSList  *last_task;
+	GList  *first_task;
+	GList  *last_task;
 
 	mrptime  first_time;
 	mrptime  last_time;
@@ -48,8 +48,8 @@ typedef struct {
 	gdouble  gantt_x0;
 	gdouble  gantt_y0;
 
-	GSList  *elements;
-	GSList  *background_elements;
+	GList  *elements;
+	GList  *background_elements;
 } Page;
 
 struct _MgGanttPrintData {
@@ -97,7 +97,7 @@ struct _MgGanttPrintData {
 	GnomeFont         *font;
 	GnomeFont         *font_bold;
 
-	GSList            *tasks;
+	GList            *tasks;
 
 	gdouble            f;
 	
@@ -205,13 +205,13 @@ print_table_header (MgGanttPrintData *data)
 static void
 print_table_tasks (MgGanttPrintData *data,
 		   gboolean          header,
-		   GSList           *tasks,
+		   GList           *tasks,
 		   gint              first)
 {
 	gchar     *str;
 	gint       work;
 	gdouble    x, y;
-	GSList    *l, *to;
+	GList    *l, *to;
 	PrintTask *ptask;
 	gint       last, i;
 
@@ -221,8 +221,8 @@ print_table_tasks (MgGanttPrintData *data,
 		last = first + data->tasks_per_page_without_header;
 	}
 	
-	l = g_slist_nth (tasks, first);
-	to = g_slist_nth (tasks, last);
+	l = g_list_nth (tasks, first);
+	to = g_list_nth (tasks, last);
 	i = 1;
 
 	gnome_print_setlinewidth (data->job->pc, 0);
@@ -371,7 +371,7 @@ print_time_header (MgGanttPrintData *data,
 
 typedef struct {
 	GtkTreeView *tree_view;
-	GSList      *list;
+	GList      *list;
 } ForeachVisibleData;
 
 static gboolean
@@ -399,14 +399,14 @@ foreach_visible_task (GtkTreeModel *model,
 		ptask->task = task;
 		ptask->depth = gtk_tree_path_get_depth (path);
 
-		fvd->list = g_slist_prepend (fvd->list, ptask);
+		fvd->list = g_list_prepend (fvd->list, ptask);
 	}
 	gtk_tree_path_free (parent_path);
 	
 	return FALSE;
 }
 
-static GSList *
+static GList *
 gantt_print_get_visible_tasks (MgGanttPrintData *data)
 {
 	ForeachVisibleData  fvd;
@@ -421,35 +421,33 @@ gantt_print_get_visible_tasks (MgGanttPrintData *data)
 				foreach_visible_task,
 				&fvd);
 
-	return g_slist_reverse (fvd.list);
+	return g_list_reverse (fvd.list);
 }
 
 static void
-gantt_print_free_print_tasks (GSList *tasks)
+gantt_print_free_print_tasks (GList *tasks)
 {
-	GSList *l;
+	GList *l;
 
 	for (l = tasks; l; l = l->next) {
 		g_free (l->data);
 	}
 }	
 
-static GSList *
+static GList *
 gantt_print_get_relations (MgGanttPrintData *data)
 {
 	GList   *tasks, *l;
 	GList   *predecessors, *p;
-	GSList  *relations = NULL;
+	GList  *relations = NULL;
 
 	tasks = mrp_project_get_all_tasks (data->project);
 	for (l = tasks; l; l = l->next) {
-		predecessors = mrp_task_get_predecessors (l->data);
+		predecessors = mrp_task_get_predecessor_relations (l->data);
 		
 		for (p = predecessors; p; p = p->next) {
-			relations = g_slist_prepend (relations, p->data);
+			relations = g_list_prepend (relations, p->data);
 		}
-
-		g_list_free (predecessors);
 	}
 
 	g_list_free (tasks);
@@ -532,8 +530,6 @@ gantt_print_get_allocated_resources_string (MgGanttPrintData  *data,
 		text = tmp_str;
 	}
 
-	g_list_free (assignments);
-
 	if (text && width) {
 		w = gnome_font_get_width_utf8 (
 			mg_print_job_get_font (data->job), text);
@@ -555,8 +551,8 @@ gantt_print_get_allocated_resources_string (MgGanttPrintData  *data,
 void
 mg_gantt_print_do (MgGanttPrintData *data)
 {
-	GSList      *relations;
-	GSList      *l;
+	GList      *relations;
+	GList      *l;
 	gdouble      x1, x2;
 	gdouble      y1, y2;
 	gint         num_tasks;
@@ -576,12 +572,12 @@ mg_gantt_print_do (MgGanttPrintData *data)
 	gchar       *str;
 	MrpCalendar *calendar;
 	MrpDay      *day;
-	GSList      *ivals;
+	GList       *ivals;
 	MrpInterval *ival;
 
 	calendar = mrp_project_get_calendar (data->project);
 	
-	num_tasks = g_slist_length (data->tasks);
+	num_tasks = g_list_length (data->tasks);
 
 	/* Go through all tasks in a first pass and layout them so that we know
 	 * where to draw relation arrows.
@@ -762,7 +758,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 					}
 
 					page = GET_PAGE (data, row, col);
-					page->elements = g_slist_prepend (page->elements, element);
+					page->elements = g_list_prepend (page->elements, element);
 				}
 				
 				t1 = t2;
@@ -785,7 +781,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 				element->resources = str;
 
 				page = GET_PAGE (data, row, col - 1);
-				page->elements = g_slist_prepend (page->elements, element);
+				page->elements = g_list_prepend (page->elements, element);
 			}
 			
 			l = l->next;
@@ -838,7 +834,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 		}
 
 		page = GET_PAGE (data, suc_coord->row, suc_coord->col);
-		page->elements = g_slist_prepend (page->elements, element);
+		page->elements = g_list_prepend (page->elements, element);
 
 		for (row = from_row; row <= to_row; row++) {
 			if (row == pre_coord->row) {
@@ -865,7 +861,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 					element->y1 = pre_coord->y;
 					
 					page = GET_PAGE (data, row, col);
-					page->elements = g_slist_prepend (page->elements, element);
+					page->elements = g_list_prepend (page->elements, element);
 				}
 			}
 
@@ -900,10 +896,12 @@ mg_gantt_print_do (MgGanttPrintData *data)
 			}
 			
 			page = GET_PAGE (data, row, suc_coord->col);
-			page->elements = g_slist_prepend (page->elements, element);
+			page->elements = g_list_prepend (page->elements, element);
 		}
 	}
 
+	g_list_free (relations);
+
 	/* Third pass, add background shading for non-work intervals. */
 	t0 = mrp_time_align_day (data->start);
 	for (row = 0; row < data->rows_of_pages; row++) {
@@ -954,7 +952,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 						element->x2 = x0 + (ival_start - data->start) / data->f;
 						
 						page = GET_PAGE (data, row, col);
-						page->background_elements = g_slist_prepend (page->background_elements, element);
+						page->background_elements = g_list_prepend (page->background_elements, element);
 					}
 					
 					ival_prev = ival_end;
@@ -973,7 +971,7 @@ mg_gantt_print_do (MgGanttPrintData *data)
 					element->x2 = x0 + (t1 - data->start) / data->f;
 					
 					page = GET_PAGE (data, row, col);
-					page->background_elements = g_slist_prepend (page->background_elements, element);
+					page->background_elements = g_list_prepend (page->background_elements, element);
 				}
 			}
 		}
@@ -1161,6 +1159,22 @@ mg_gantt_print_do (MgGanttPrintData *data)
 					gnome_print_closepath (data->job->pc);
 					gnome_print_fill (data->job->pc);
 					break;
+				case SUMMARY_MIDDLE:
+						mg_print_job_moveto (data->job,
+							     element->x2,
+							     element->y1 + 2 * data->summary_thick);
+					mg_print_job_lineto (data->job,
+							     element->x1,
+							     element->y1 + 2 * data->summary_thick);
+					mg_print_job_lineto (data->job,
+							     element->x1,
+							     element->y1 + data->summary_thick);
+					mg_print_job_lineto (data->job,
+							     element->x2,
+							     element->y1 + data->summary_thick);
+					gnome_print_closepath (data->job->pc);
+					gnome_print_fill (data->job->pc);
+					break;
 				case RELATION_ARROW_DOWN:
 					mg_print_job_moveto (data->job,
 							     element->x1,
@@ -1248,8 +1262,9 @@ mg_gantt_print_data_new (MgView      *view,
 {
 	MgGanttPrintData *data;
 	GnomeFont        *font;
-	GSList           *tasks = NULL, *l;
+	GList            *tasks = NULL, *l;
 	gint              num_tasks;
+	gdouble           max_name_width = 0.0;
 
 	data = g_new0 (MgGanttPrintData, 1);
 
@@ -1258,7 +1273,7 @@ mg_gantt_print_data_new (MgView      *view,
 	data->project = mg_main_window_get_project (view->main_window);
 
 	data->tree_view = tree_view;
-	
+
 	data->show_critical = show_critical;
 	data->level = level;
 	
@@ -1266,7 +1281,7 @@ mg_gantt_print_data_new (MgView      *view,
 	 * zoom level in the gantt chart, which actually is calculated to have a
 	 * "good feel" :). We scale it width the paper size here though...
 	 */
-	data->f = 500 / pow (2, level - 19) / data->job->width;
+	data->f = 1000 / pow (2, level - 19) / data->job->width;
 
 	data->major_unit = mg_scale_conf[level].major_unit;
 	data->major_format = mg_scale_conf[level].major_format;
@@ -1276,27 +1291,6 @@ mg_gantt_print_data_new (MgView      *view,
 
 	font = mg_print_job_get_font (job);
 	
-	data->name_x1 = 0;
-	data->name_x2 = data->name_x1 + gnome_font_get_width_utf8 (font, "TASKNAMETASKNAME");
-
-	data->work_x1 = data->name_x2;
-	data->work_x2 = data->work_x1 + gnome_font_get_width_utf8 (font, "WORKW");
-
-	data->tree_x1 = 0;
-	data->tree_x2 = data->work_x2;
-	
-	data->row_height = 2 * mg_print_job_get_font_height (job);
-
-	data->header_height = 2 * data->row_height;
-
-	/* Calculate drawing "constants". */
-	data->summary_height = 0.36 * data->row_height;
-	data->summary_thick  = 0.12 * data->row_height;
-	data->summary_slope  = 0.28 * data->row_height;
-	data->milestone_size = 0.20 * data->row_height;
-	data->arrow_height   = 0.24 * data->row_height;
-	data->arrow_width    = 0.16 * data->row_height;
-
 	data->task_start_coords = g_hash_table_new (NULL, NULL);
 	data->task_finish_coords = g_hash_table_new (NULL, NULL);
 
@@ -1305,7 +1299,7 @@ mg_gantt_print_data_new (MgView      *view,
 	
 	tasks = gantt_print_get_visible_tasks (data);
 	data->tasks = tasks;
-	num_tasks = g_slist_length (tasks);
+	num_tasks = g_list_length (tasks);
 
 	data->finish = data->start;
 	
@@ -1318,27 +1312,64 @@ mg_gantt_print_data_new (MgView      *view,
 		gchar     *name;
 		mrptime    finish;
 		gdouble    width;
+		gdouble    name_width;
 		gchar     *str;
 		
 		g_object_get (task, "name", &name, "finish", &finish, NULL);
-		
+
+		name_width = gnome_font_get_width_utf8 (font, name) + 
+			       ptask->depth * INDENT_FACTOR * data->job->x_pad;
+		if (max_name_width < name_width)
+			max_name_width = name_width;
+
 		gantt_print_get_allocated_resources_string (data, task, &str, &width);
 
 		data->finish = MAX (data->finish, finish);/* + width * data->f);*/
 	}
 
+	data->name_x1 = 0;
+	data->name_x2 = data->name_x1 + max_name_width + gnome_font_get_width_utf8
+		(font, "WW");
+	
+	data->work_x1 = data->name_x2;
+	data->work_x2 = data->work_x1 + gnome_font_get_width_utf8 (font, "WORKW");
+
+	data->tree_x1 = 0;
+	data->tree_x2 = data->work_x2;
+	
+	data->row_height = 2 * mg_print_job_get_font_height (job);
+	
+	data->header_height = 2 * data->row_height;
+	
+	/* Calculate drawing "constants". */
+	data->summary_height = 0.36 * data->row_height;
+	data->summary_thick  = 0.12 * data->row_height;
+	data->summary_slope  = 0.28 * data->row_height;
+	data->milestone_size = 0.40 * data->row_height;
+	data->arrow_height   = 0.24 * data->row_height;
+	data->arrow_width    = 0.16 * data->row_height;
+
 	if (num_tasks > 0) {
+		data->tasks_per_page_with_header = data->job->height / data->row_height;
+		data->tasks_per_page_without_header = (data->job->height - data->header_height) /
+			data->row_height;
+
 		data->cols_of_pages = ceil (((data->finish - data->start) /
 					     data->f + data->tree_x2 - data->tree_x1) /
 					    data->job->width);
-		data->rows_of_pages = ceil ((num_tasks * data->row_height + data->header_height) /
-					    data->job->height);
-		
-		data->pages = g_new0 (Page, data->cols_of_pages * data->rows_of_pages);
 
-		data->tasks_per_page_without_header = data->job->height / data->row_height;
-		data->tasks_per_page_with_header = (data->job->height - data->header_height) /
-			data->row_height;
+		data->rows_of_pages = ceil ((num_tasks * data->row_height + data->header_height) /
+					    (data->job->height - data->row_height));
+ 		
+		if (data->tasks_per_page_without_header * (data->rows_of_pages - 2) +
+		    data->tasks_per_page_with_header >= num_tasks) {
+			data->rows_of_pages--;
+		}
+
+		data->cols_of_pages = MAX (1, data->cols_of_pages);
+		data->rows_of_pages = MAX (1, data->rows_of_pages);
+		
+ 		data->pages = g_new0 (Page, data->cols_of_pages * data->rows_of_pages);
 	}
 	
 	return data;
