@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2002 CodeFactory AB
- * Copyright (C) 2002 Richard Hult <rhult@codefactory.se>
+ * Copyright (C) 2002-2003 CodeFactory AB
+ * Copyright (C) 2002-2003 Richard Hult <rhult@codefactory.se>
  * Copyright (C) 2002 Mikael Hallendal <micke@codefactory.se>
  * Copyright (C) 2002 Alvaro del Castillo <acs@barrapunto.com>
  *
@@ -535,26 +535,26 @@ task_tree_tree_view_button_press_event (GtkTreeView    *tree_view,
 			gtk_tree_selection_select_path (gtk_tree_view_get_selection (tv), path);
 
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 2), TRUE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_SUBTASK), TRUE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 3), TRUE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_REMOVE), TRUE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 4), TRUE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_UNLINK), TRUE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 5), TRUE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_EDIT), TRUE);
 			
 			gtk_tree_path_free (path);
 		} else {
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (tv));
 
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 2), FALSE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_SUBTASK), FALSE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 3), FALSE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_REMOVE), FALSE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 4), FALSE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_UNLINK), FALSE);
 			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, 5), FALSE);
+				gtk_item_factory_get_widget_by_action (factory, POPUP_EDIT), FALSE);
 		}
 		
 		gtk_item_factory_popup (factory, event->x_root, event->y_root,
@@ -1009,7 +1009,7 @@ task_tree_property_data_func (GtkTreeViewColumn *tree_column,
 	/* FIXME: implement mrp_object_get_property like
 	 * g_object_get_property that takes a GValue. 
 	 */
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
@@ -1101,7 +1101,7 @@ task_tree_property_value_edited (GtkCellRendererText *cell,
 	/* FIXME: implement mrp_object_set_property like
 	 * g_object_set_property that takes a GValue. 
 	 */
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
@@ -1175,7 +1175,7 @@ task_tree_property_added (MrpProject  *project,
 
 	data = g_new0 (ColPropertyData, 1);
 
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	/* The costs are edited in resources view 
 	if (type == MRP_PROPERTY_TYPE_COST) {
@@ -1749,22 +1749,24 @@ mg_task_tree_unlink_task (MgTaskTree *tree)
 	for (l = list; l; l = l->next) {
 		task = l->data;
 
-		relations = g_list_copy (mrp_task_get_predecessors (task));
+		relations = g_list_copy (mrp_task_get_predecessor_relations (task));
 		for (r = relations; r; r = r->next) {
 			relation = r->data;
 			
 			mrp_task_remove_predecessor (
 				task, mrp_relation_get_predecessor (relation));
 		}
+
 		g_list_free (relations);
 		
-		relations = g_list_copy (mrp_task_get_successors (task));
+		relations = g_list_copy (mrp_task_get_successor_relations (task));
 		for (r = relations; r; r = r->next) {
 			relation = r->data;
 			
 			mrp_task_remove_predecessor (
 				mrp_relation_get_successor (relation), task);
 		}
+
 		g_list_free (relations);
 	}
 	
