@@ -196,6 +196,7 @@ void           deactivate                            (MgView               *view
 void           init                                  (MgView               *view,
 						      MgMainWindow         *main_window);
 gchar         *get_label                             (MgView               *view);
+gchar         *get_menu_label                        (MgView               *view);
 gchar         *get_icon                              (MgView               *view);
 GtkWidget     *get_widget                            (MgView               *view);
 void           print_init                            (MgView            *view,
@@ -341,6 +342,14 @@ get_label (MgView *view)
 	return _("Resources");
 }
 
+G_MODULE_EXPORT gchar *
+get_menu_label (MgView *view)
+{
+	g_return_val_if_fail (MG_IS_VIEW (view), NULL);
+	
+	return _("_Resources");
+}
+
 G_MODULE_EXPORT gchar *
 get_icon (MgView *view)
 {
@@ -1024,7 +1033,8 @@ resource_view_setup_tree_view (MgView *view)
 
 	/* Custom properties for costs added by default */
 	project = mg_main_window_get_project (view->main_window);
-	properties = mrp_project_get_properties (project, MRP_TYPE_RESOURCE);
+	properties = mrp_project_get_properties_from_type (project, 
+							   MRP_TYPE_RESOURCE);
 
 	for (l = properties; l; l = l->next) {	
 		resource_view_property_added (project, MRP_TYPE_RESOURCE, l->data, view);
@@ -1231,7 +1241,7 @@ resource_view_property_value_edited (GtkCellRendererText *cell,
 	/* FIXME: implement mrp_object_set_property like
 	 * g_object_set_property that takes a GValue. 
 	 */
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
@@ -1328,7 +1338,7 @@ resource_view_cell_group_show_popup (MgCellRendererList *cell,
 	i = 0;
 	index = 0;
 	list = NULL;
-	groups = mrp_project_get_groups (project);
+	groups = g_list_copy (mrp_project_get_groups (project));
 	groups = g_list_prepend (groups, NULL);
 
 	for (l = groups; l; l = l->next) {
@@ -1420,8 +1430,6 @@ resource_view_project_loaded_cb (MrpProject *project, MgView *view)
 				    COL_RESOURCE, MRP_RESOURCE (l->data),
 				    -1);
 	}
-	g_list_free (resources);
-
 	gtk_tree_view_set_model (tree_view, model);
 
  	g_object_unref (model);
@@ -1443,7 +1451,7 @@ resource_view_property_added (MrpProject  *project,
 
 	data = g_new0 (ColPropertyData, 1);
 
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	if (object_type != MRP_TYPE_RESOURCE ||
 	    !mrp_property_get_user_defined (property)) {
@@ -1627,7 +1635,7 @@ resource_view_property_data_func    (GtkTreeViewColumn *tree_column,
 	/* FIXME: implement mrp_object_get_property like
 	 * g_object_get_property that takes a GValue. 
 	 */
-	type = mrp_property_get_type (property);
+	type = mrp_property_get_property_type (property);
 
 	switch (type) {
 	case MRP_PROPERTY_TYPE_STRING:
